@@ -1,6 +1,5 @@
 from __future__ import annotations
 import io
-from turtle import RawTurtle
 import typing
 from typing import List, Optional, Callable, Tuple
 
@@ -183,7 +182,8 @@ class PureThriftFormatter(object):
 
     Type_ruleContext = _gen_inline_Context(join='')
     Const_ruleContext = _gen_inline_Context(join='')
-    Enum_fieldContext = _gen_inline_Context(join=' ',
+    Enum_fieldContext = _gen_inline_Context(
+        join=' ',
         tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
     Field_ruleContext = _gen_inline_Context(join='')
     Type_ruleContext = _gen_inline_Context(join='')
@@ -263,7 +263,7 @@ class ThriftFormatter(PureThriftFormatter):
         self._field_padding: int = 0
         self._last_token_index: int = -1
 
-    def option(self, comment: Optional[bool]=None, patch: Optional[bool]=None, indent:Optional[int]=None):
+    def option(self, comment: Optional[bool] = None, patch: Optional[bool] = None, indent: Optional[int] = None):
         if comment is not None:
             self._option_comment = comment
         if patch is not None:
@@ -353,24 +353,19 @@ class ThriftFormatter(PureThriftFormatter):
         if is_last and isinstance(node.children[-1], ThriftParser.List_separatorContext):
             node.children.pop()
 
-    def _calc_field_padding(self, fields: List[ParseTree]):
+    def _calc_subfields_padding(self, fields: List[ParseTree]):
         if not fields:
             return 0
 
-        lengths = []
-        # TODO: calc real field padding
+        padding = 0
         for i, field in enumerate(fields):
-            lengths.append(0)
-            def calc_field(node: ParseTree):
-                if not isinstance(node, TerminalNodeImpl):
-                    return
-                lengths[i] += 1  # join
-                lengths[i] += len(node.symbol.text)
-            self.walk_node(field, calc_field)
-        return max(lengths)
+            out = PureThriftFormatter().format_node(field)
+            if len(out) > padding:
+                padding = len(out)
+        return padding
 
     def before_subfields_hook(self, fields: List[ParseTree]):
-        self._field_padding = self._calc_field_padding(fields)
+        self._field_padding = self._calc_subfields_padding(fields)
         self._field_padding += self._option_indent
 
     def after_subfields_hook(self, _: List[ParseTree]):
