@@ -7,18 +7,21 @@ from .core import ThriftData, ThriftFormatter
 
 
 @click.command()
-@click.option('-d', '--dir',
-    type=click.Path(exists=True, file_okay=False, dir_okay=True),)
-@click.option('-w', '--write', is_flag=True,
+@click.option(
+    '-d', '--dir', type=click.Path(exists=True, file_okay=False, dir_okay=True))
+@click.option(
+    '-w', '--write', is_flag=True,
     help='Write to file instead of stdout, default true when dir was set')
-@click.option('-i', '--indent', type=click.IntRange(min=0), default=None,
+@click.option(
+    '-i', '--indent', type=click.IntRange(min=0), default=None,
     help='struct/enum/service sub fields indent, default {}'.format(
         ThriftFormatter.DEFAULT_INDENT))
-@click.option('--no-patch', is_flag=True,
-    help='not patch thrift file')
-@click.option('--remove-comment', is_flag=True, default=False,
-    help='remove all comment')
-@click.argument('file',
+@click.option(
+    '--no-patch', is_flag=True, help='not patch thrift file')
+@click.option(
+    '--remove-comment', is_flag=True, help='remove all comment')
+@click.argument(
+    'file',
     type=click.Path(exists=True, file_okay=True, dir_okay=False), required=False)
 def main(dir, write, indent, no_patch, remove_comment, file):
     if not dir and not file:
